bleIdentifierForGuid method

String? bleIdentifierForGuid(
  1. String guid
)

Exposes the BLE identifier for a device guid, or null if not present.

Used in tests to verify that _bleIdentifiers was correctly populated or cleared after device arrival and removal events.

Implementation

String? bleIdentifierForGuid(String guid) => _bleIdentifiers[guid];