AppInfo class

This is the app information used to access the API. These credentials are generated when you register your app on the Socket Mobile website.

Annotations
  • @freezed

Constructors

AppInfo({String? appIdAndroid, String? appIdIos, String? appKeyAndroid, String? appKeyIos, required String developerId})
const
factory
AppInfo.fromJson(Map<String, Object?> json)
factory

Properties

appIdAndroid → String?
no setterinherited
appIdIos → String?
no setterinherited
appKeyAndroid → String?
no setterinherited
appKeyIos → String?
no setterinherited
copyWith → $AppInfoCopyWith<AppInfo>
no setterinherited
developerId → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited