CaptureEvent class

Response from the capture library based on user interaction. When you use the scanner to scan a barcode, you will recieve a CaptureEvent of the decoded data.

Annotations
  • @freezed

Constructors

CaptureEvent({required int id, required int type, @Default.new(<String, dynamic>{}) dynamic value, int? handle, required dynamic result})
const
factory
CaptureEvent.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $CaptureEventCopyWith<CaptureEvent>
no setterinherited
decodedData → DecodedData
no setter
deviceInfo → DeviceInfo
no setter
handle → int?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
result → dynamic
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String
no setter
type → int
no setterinherited
value → dynamic
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited