CaptureException class

Wraps any errors in a uniform class to ensure user only has to check for one data type and one set of properties.

Implemented types

Constructors

CaptureException(int code, String message, [String? method, String? details])

Properties

code ↔ int
getter/setter pair
details ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String
getter/setter pair
method ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited