CaptureNotification class

This is the notification wrapper to alert the user that a capture event was recorded.

Constructors

CaptureNotification(CaptureEvent event, int? handle)

Properties

event ↔ CaptureEvent
getter/setter pair
handle ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited