CaptureProperty class

Class for properties recieved/submitted in requests to Capture library. Capture properties can represent a device name, device type, monitor mode, etc.

Annotations
  • @freezed

Constructors

CaptureProperty({required int id, required int type, @protected required dynamic value})
const
factory
CaptureProperty.fromJson(Map<String, Object?> json)
factory

Properties

array → List<int>
no setter
byte → int
no setter
copyWith → $CapturePropertyCopyWith<CaptureProperty>
no setterinherited
dataSource → DataSource
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
object → Object
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String
no setter
type → int
no setterinherited
ulong → int
no setter
value → dynamic
no setterinherited
version → Version
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited