CaptureVersion class

What version of capture is being used.

Constructors

CaptureVersion([int? major, int? middle, int? minor, int? build, int? year, int? month, int? day, int? hour, int? minute])

Properties

build ↔ int?
getter/setter pair
day ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ int?
getter/setter pair
major ↔ int?
getter/setter pair
middle ↔ int?
getter/setter pair
minor ↔ int?
getter/setter pair
minute ↔ int?
getter/setter pair
month ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
year ↔ int?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object message) → CaptureVersion