DataSource class

Where the event data stems from.

Annotations
  • @freezed

Constructors

DataSource({required int id, required String name, required int status, required int flags})
const
factory
DataSource.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $DataSourceCopyWith<DataSource>
no setterinherited
flags → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object message) → DataSource