DecodedData class

Data recieved from a device scan; response from device scan will be a capture event containing decoded data.

Annotations
  • @freezed

Constructors

DecodedData({required int id, required String name, required List<int> data, required String? tagId})
const
factory
DecodedData.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $DecodedDataCopyWith<DecodedData>
no setterinherited
data → List<int>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagId → String?
no setterinherited

Methods

dataAsString({Encoding codec = const Utf8Codec()}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited