DiscoveredDeviceInfo class

Information about a BLE device discovered during a scan.

Annotations
  • @freezed

Constructors

DiscoveredDeviceInfo({required String name, required String identifierUuid, required String serviceUuid})
const
factory
DiscoveredDeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $DiscoveredDeviceInfoCopyWith<DiscoveredDeviceInfo>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
identifierUuid String
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceUuid String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited