CaptureDataSourceFlags class

Flags for the different data sources in capture events.

Constructors

CaptureDataSourceFlags()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

param → const int
the data source contains some parameters
status → const int
the data source contains a status