BluetoothDiscoveryMode class

The Bluetooth technology used to make a discovery of devices in the vicinity

Constructors

BluetoothDiscoveryMode()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bluetoothClassic → const int
Discovery for Bluetooth Classic devices.
bluetoothLowEnergy → const int
Discovery for Bluetooth LE devices such as S550, S370, S320, S721.