ConnectBeepConfig class

The connect beep configuration allows to turn off or on the connection beep when the scanner connects

Constructors

ConnectBeepConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

beep → const int
The device beeps when connecting to the host.
noBeep → const int
The device won't beep upon connection to a host.