good constant
int
const good
Mask applied on the Good local decode action result
Implementation
static const int good = 1;
Mask applied on the Good local decode action result
static const int good = 1;