deviceId constant
int
const deviceId
Set your own Device Id that will return a Single Partnership Web page with a QRcode to scan
Implementation
static const int deviceId = 5;
Set your own Device Id that will return a Single Partnership Web page with a QRcode to scan
static const int deviceId = 5;