StandConfig class

The stand configuration defines the operational mode of the device when used with a stand.

Constructors

StandConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

autoMode → const int
Bluetooth Classic: Auto mode On stand engine in presentation mode On stand engine hibernate disabled On stand charging led state not show On stand scanner turns on immediately On stand power timers disabled On stand connection retries forever Off stand does nothing, engine remains in presentation mode Off stand trigger press causes engine to enter level mode Engine in level mode battery led state reported Engine in level mode hibernate enabled Engine in level mode power off timers running Engine in level mode connection retries halt after max count Bluetooth LE: Same as DetectMode, but if you use the trigger button while it's out of the stand it switches to a normal trigger operation until it returns to the stand in which it switches to presentation mode. If it is removed from the stand it stays in presentation mode until the trigger is pressed at least once.
detectMode → const int
Bluetooth Classic: Detect mode On stand engine in presentation mode On stand engine hibernate disabled On stand charging led state not show On stand scanner turns on immediately On stand power timers disabled On stand connection retries forever Off stand engine in level mode Off stand battery led state reported Off stand engine hibernate enabled Off stand power off timers running Off stand connection retries halt after max count Bluetooth LE: The device switches in or out of presentation mode when it's in or out respectively from the stand
disabled → const int
Bluetooth Classic: Disabled the stand config property and sets the scanner as it is intended Bluetooth LE: Scanner does not switch to presentation mode
mobileMode → const int
Bluetooth Classic: Mobile mode Works like today existing firmware Engine is always in trigger mode Engine hibernate enabled Bluetooth LE: Identical to disabled mode
standMode → const int
Bluetooth Classic: Stand mode Engine always in presentation mode Engine hibernate disabled Scanner turns on immediately Power timers disabled Connection retries forever Bluetooth LE: The device switches to presentation mode, always, in or out of the stand,