autoMode constant
Bluetooth Classic: Auto mode On stand engine in presentation mode On stand engine hibernate disabled On stand charging led state not show On stand scanner turns on immediately On stand power timers disabled On stand connection retries forever Off stand does nothing, engine remains in presentation mode Off stand trigger press causes engine to enter level mode Engine in level mode battery led state reported Engine in level mode hibernate enabled Engine in level mode power off timers running Engine in level mode connection retries halt after max count Bluetooth LE: Same as DetectMode, but if you use the trigger button while it's out of the stand it switches to a normal trigger operation until it returns to the stand in which it switches to presentation mode. If it is removed from the stand it stays in presentation mode until the trigger is pressed at least once.
Implementation
static const int autoMode = 4;