standMode constant

int const standMode

Bluetooth Classic: Stand mode Engine always in presentation mode Engine hibernate disabled Scanner turns on immediately Power timers disabled Connection retries forever Bluetooth LE: The device switches to presentation mode, always, in or out of the stand,

Implementation

static const int standMode = 2;