ThemeSelectionMask class

Mask for the Theme selection property. It applies the theme selection on the given device(s) set with the mask

Constructors

ThemeSelectionMask()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

all → const int
Mask applied on the Default, Nfc and Barcode devices
barcode → const int
Mask applied on the Barcode device
Default → const int
Mask applied on the Default device
defaultBarcode → const int
Mask applied on the Default and Barcode devices
defaultNfc → const int
Mask applied on the Default and Nfc devices
nfc → const int
Mask applied on the Nfc device
nfcBarcode → const int
Mask applied on the Nfc and Barcode devices