SoftScan class

Constructors

SoftScan()

Properties

disable ↔ int
getter/setter pair
enable ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notSupported ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited