TriggerMode class

Constructors

TriggerMode()

Properties

autoLock ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localOnly ↔ int
getter/setter pair
normalLock ↔ int
getter/setter pair
presentation ↔ int
getter/setter pair
remoteAndLocal ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited