Params class

Used in requests as well as storing device or property details.

Annotations
  • @freezed

Constructors

Params({required int handle, String? guid, CaptureProperty? property})
const
factory
Params.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $ParamsCopyWith<Params>
no setterinherited
guid → String?
no setterinherited
handle → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
property → CaptureProperty?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited