CapturePlugin class

Constructors

CapturePlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cancelSubscription() Future
dummyFunction() Future
setCustomViewMode({required bool enabled}) Future<void>
startCaptureService() Future
startSocketCamExtension(int? clientHandle, Function callback) Future<void>
stopSocketCamExtension() Future<void>

Constants

eventChannel → const EventChannel
platform → const MethodChannel