DecodeLocalActionSelectionMask class

Mask for the Decode Local Action selection property. It applies the decode local action selection on the given device(s) set with the mask

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bad → const int
Mask applied on the Bad local decode action result
good → const int
Mask applied on the Good local decode action result