mobileMode constant
int
const mobileMode
Bluetooth Classic: Mobile mode Works like today existing firmware Engine is always in trigger mode Engine hibernate enabled Bluetooth LE: Identical to disabled mode
Implementation
static const int mobileMode = 1;