HttpTransport class
Main transport for establishing and making requests on Android. utilizing json rpc as well as Websockets to establish channel.
Constructors
- HttpTransport(Logger? logger, [bool? isWeb])
Properties
- getTransport ↔ Transport Function(Logger logger)
-
getter/setter pairinherited
-
handles
↔ List<
Params> -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String?
-
getter/setter pair
- hostWebsocket ↔ String
-
getter/setter pair
- isWeb ↔ bool?
-
getter/setter pair
- logger ↔ Logger?
-
getter/setter pair
- onEventNotification ↔ void Function(dynamic, int)?
-
getter/setter pair
- rpcId ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transportHandle ↔ int?
-
getter/setter pairinherited
- websocket ↔ WebSocketChannel?
-
getter/setter pair
Methods
-
close(
int handle) → Future< int> -
Piggyback Capture's close and use parameters and interfaces unique to http connections
Implement JSON Rpc protocols.
override
-
generateHandle(
) → int -
inherited
-
getProperty(
int clientOrDeviceHandle, CaptureProperty property) → Future< CaptureProperty> -
Piggyback Capture's getProperty and use parameters and interfaces unique to http connections
Implement JSON Rpc protocols.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notification(
dynamic event, [int? handle]) → dynamic - Function to attach passed onEventNotification to websocket channel listener.
-
openClient(
String host, AppInfo appInfo, Function notification) → Future< int> -
Piggyback Capture's openClient and use parameters and interfaces unique to http connections
Implement JSON Rpc protocols.
override
-
openDevice(
int clientHandle, String guid) → Future< int> -
Piggyback Capture's openDevice and use parameters and interfaces unique to http connections
Implement JSON Rpc protocols.
override
-
openWebSocket(
) → void - Opens a websocket for receiving Capture events.
-
sendRequest(
JRpcRequest request) → Future< JRpcResponse> - Helper function for constructing, validating and handling various HTTP requests for capture.
-
setProperty(
int clientOrDeviceHandle, CaptureProperty property) → Future< CaptureProperty> -
Piggyback Capture's setProperty and use parameters and interfaces unique to http connections
Implement JSON Rpc protocols.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited